==> libbpp-seq-omics_2.2.0.orig.tar.gz: bpp-seq-omics-2.2.0/src/Bpp/Seq/Feature/FeatureReader.h <==
//
// File: FeatureReader.h
// Created by: Julien Dutheil
// Created on: Thu Nov 22 2012
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#ifndef _FEATUREREADER_H_
#define _FEATUREREADER_H_

#include "SequenceFeature.h"

//From bpp-core:
#include <Bpp/Exceptions.h>

//From the STL:
#include <string>
#include <vector>

namespace bpp {

/**
 * @brief Interface for feature readers.
 *
 * @author Julien Dutheil, Sylvain Gaillard
 */
class FeatureReader
{
  public:
    FeatureReader() {}
    virtual ~FeatureReader() {}

  public:
    virtual bool hasMoreFeature() const = 0;
    virtual const BasicSequenceFeature nextFeature() throw (Exception) = 0;
    virtual void getAllFeatures(SequenceFeatureSet& features) = 0;
    virtual void getFeaturesOfType(const std::string& type, SequenceFeatureSet& features) = 0;
    virtual void getFeaturesOfSequence(const std::string& seqId, SequenceFeatureSet& features) = 0;
   
};

} //end of namespace bpp

#endif //_FEATUREREADER_H_

==> libbpp-seq-omics_2.4.0.orig.tar.gz: bpp-seq-omics-2.4.0/src/Bpp/Seq/Feature/FeatureReader.h <==
//
// File: FeatureReader.h
// Created by: Julien Dutheil
// Created on: Thu Nov 22 2012
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#ifndef _FEATUREREADER_H_
#define _FEATUREREADER_H_

#include "SequenceFeature.h"

//From bpp-core:
#include <Bpp/Exceptions.h>

//From the STL:
#include <string>
#include <vector>

namespace bpp {

/**
 * @brief Interface for feature readers.
 *
 * @author Julien Dutheil, Sylvain Gaillard
 */
class FeatureReader
{
  public:
    FeatureReader() {}
    virtual ~FeatureReader() {}

  public:
    virtual bool hasMoreFeature() const = 0;
    virtual const BasicSequenceFeature nextFeature() = 0;
    virtual void getAllFeatures(SequenceFeatureSet& features) = 0;
    virtual void getFeaturesOfType(const std::string& type, SequenceFeatureSet& features) = 0;
    virtual void getFeaturesOfSequence(const std::string& seqId, SequenceFeatureSet& features) = 0;
   
};

} //end of namespace bpp

#endif //_FEATUREREADER_H_
